//
//  P4MenuController.h
//  MBMenuExtra
//
//  Created by Michael Bishop on 10/25/09.
//  Copyright 2009 Perforce Software. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import "P4ClientApi.h"
#import "SCMSubmitDialog.h"
#import "NSObject+BlockObservation.h"

@class P4Spec, P4Client, P4MenuApplicationDelegate, P4MenuStatusViewController, P4MenuLocalFile, P4LocalFileManager, P4FileObserverToken, P4ServerEntry, P4Connection;

enum eP4FileType
{
    kP4FileTypeText
    , kP4FileTypeBinary
    , kP4FileTypeApple
    , kP4FileTypeSymlink
    , kP4FileTypeResource
    , kP4FileTypeUnicode
    , kP4FileTypeUTF16
    , kP4FileTypeUnknown
};

@interface P4MenuController : NSObject <SCMSubmitter>
{
    IBOutlet NSMenu     *           _menu;
    IBOutlet NSMenuItem *           _statusMenuItem;
    IBOutlet NSMenuItem *           _sendDebugLogMenuItem;
    IBOutlet NSView *               _configurationPane;
    IBOutlet NSTextField *          _portTextField;
    IBOutlet NSComboBox *           _userComboBox;
    IBOutlet NSTextField *          _passwordField;
    IBOutlet NSImageView *          _passwordWarningImage;
    IBOutlet NSArrayController *    serversController;
    IBOutlet NSImageView *          _serverStatusIcon;
    BOOL                            _enabled;
    SCMSubmitDialog *               _submitDialogController;
    P4MenuStatusViewController *    _statusViewController;
    AMBlockToken *                  _statusViewControllerObservationToken;
    IBOutlet NSArrayController *    _allClientsController;
@private
    NSStatusItem        *           _menuStatusItem;
    
    __weak P4MenuApplicationDelegate * _scmMenuExtraControllerWeakRef;

    NSArray      *                  _servers;

    NSDictionary *           _currentFileFStatInfo;
    NSDictionary *           _currentAdditionalFileInfo;
    P4Spec *           _currentLocalFileChange;
    P4MenuLocalFile      *          _currentLocalFile;
    NSString      *          _currentWindowTitle;

    P4FileObserverToken      *          _currentObservationToken;
    
    P4Client * _currentClient;
    P4ServerEntry * _currentServerEntry;
    P4Connection * _problemConnection;

}

-(id)initWithMainController:(P4MenuApplicationDelegate*)mainController;

@property (nonatomic, readwrite) BOOL enabled;
@property (readonly) NSView * preferencePaneView;
@property (readonly) NSImage * preferencePaneIcon;
@property (readonly) NSString * preferencePaneTitle;
@property (readwrite, copy) NSArray * servers;

@property (nonatomic, readwrite, copy) NSString * currentWindowTitle;
@property (nonatomic, readwrite, retain) P4MenuLocalFile * currentLocalFile;
@property (nonatomic, readonly, copy) NSDictionary * currentLocalFileFStatInfo;
@property (nonatomic, readonly, retain) P4Spec * currentLocalFileChange;
@property (nonatomic, readonly, retain) P4LocalFileManager * currentFileManager;
@property (nonatomic, readonly, retain) P4Client * currentClient;
@property (nonatomic, readonly, retain) P4ServerEntry * currentServerEntry;

-(IBAction)sync:(id)sender;
-(IBAction)toggleLock:(id)sender;
-(IBAction)diff:(id)sender;
-(IBAction)openForAdd:(id)sender;
-(IBAction)openForEdit:(id)sender;
-(IBAction)openForDelete:(id)sender;
-(IBAction)revert:(id)sender;
-(IBAction)dummyStatusItem:(id)sender;
-(IBAction)refreshAll:(id)sender;
-(IBAction)showSubmitDialog:(id)sender;
-(IBAction)sendDebugLog:(id)sender;

-(P4LocalFileManager*)fileManagerForLocalPath:(NSString*)localPath;

@end
